==> anonnet-0.0.1-20011112.tgz: anonnet/src/conf.h <==
/* ==========================================================================
 * AnonNet - Anonymous Network Project
 * --------------------------------------------------------------------------
 * Copyright (C) 2001  William Ahern
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 * ==========================================================================
 */

#include "common.h" 
#include "options.h"
#include "thread.h"

#ifndef _CONF_H
#define _CONF_H 1


/* Defaults */
#ifndef DEFAULT_CONFIG
	#define DEFAULT_CONFIG PACKAGE ## "rc"
#endif

#ifndef DEFAULT_PORT
	#define DEFAULT_PORT 80
#endif

#ifndef DEFAULT_VERBOSITY
	#define DEFAULT_VERBOSITY 3
#endif

#ifndef MAX_VERBOSITY
	#define MAX_VERBOSITY 4
#endif

typedef struct {
	object_t __obj; /* inherit object */
	char *__random; /* hold default string to compare against for memory leaks */
	char *__user;
	char *__group;

	unsigned short port;
	char *random;
	unsigned short verbosity;
	bool daemon;
	char *user;
	char *group;
	bool enable_error;
	bool enable_warn;
	bool enable_info;
	bool enable_debug;
} conf_t;

conf_t conf;

void conf_init(void);
bool conf_parse(void);
void conf_destroy(void);

#endif /* _CONF_H */

==> anonnet-0.0.1-20021020.tgz: anonnet/src/conf.h <==
/* ==========================================================================
 * AnonNet - Anonymous Network Project
 * --------------------------------------------------------------------------
 * Copyright (C) 2001  William Ahern
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 * ==========================================================================
 */

#include <config.h>

#include <signal.h>

#include "common.h" 
#include "options.h"
#include "thread.h"

#ifndef _CONF_H
#define _CONF_H 1


#define MAX_VERBOSITY 5


typedef struct {
	object_t __obj; /* inherit object */
	bool init;

	/* store static string pointers so we don't free() them */
	char *__random;
	char *__user;
	char *__group;
	char *__prime;

	char *config;
	unsigned short port;
	char *listen;
	char *random;
	char *prime;
	unsigned short verbosity;
	bool daemon;
	char *user;
	char *group;
	bool enable_error;
	bool enable_warn;
	bool enable_info;
	bool enable_debug;
	bool enable_dump;
	bool enable_track_source;
	bool enable_track_func;
	bool enable_track_thread;
} conf_t;

sig_atomic_t __conf_initialized;
conf_t conf;

void conf_init(void);
void conf_parse(void);
void conf_destroy(void);
void conf_reload(void);

#endif /* _CONF_H */
